const TerserPlugin = require("terser-webpack-plugin");
const devServer = {
  hot: true,
  magicHtml: true,
  server: "http",
  port: 9000,
  host: "0.0.0.0",
  allowedHosts: "all",
  static: { directory: "./" },
  headers: {
    "Access-Control-Allow-Origin": "*",
    "Access-Control-Allow-Methods": "GET, POST, PUT, DELETE, PATCH, OPTIONS",
    "Access-Control-Allow-Headers":
      "X-Requested-With, content-type, Authorization",
  },
};

const config = {
  optimization: {
    minimize: true,
    minimizer: [
      new TerserPlugin({
        terserOptions: {
          output: {
            comments: false,
          },
        },
      }),
    ],
  },
  mode: "development",
  entry: "./src/main.tsx",
  resolve: {
    extensions: [".ts", ".tsx", ".js", ".jsx", ".json", ".css", ".less"],
  },
  externals: { react: "React", "react-dom": "ReactDOM" },
  output: {
    filename: "app.js",
    libraryTarget: "umd",
    library: "card-graphic",
  },
  devServer,
  module: {
    rules: [
      {
        test: /\.(c|le)ss$/,
        use: [
          "style-loader",
          {
            loader: "css-loader",
            options: {
              modules: { localIdentName: "[name]__[local]--[hash:base64:5]" },
            },
          },
          {
            loader: "less-loader",
            options: {
              lessOptions: { javascriptEnabled: true },
            },
          },
        ],
      },
      {
        test: /\.(js|jsx|ts|tsx)$/,
        exclude: /node_modules/,
        loader: "babel-loader",
        options: {
          cacheDirectory: true,
          plugins: [],
          presets: [
            "@babel/preset-env",
            "@babel/preset-react",
            "@babel/preset-typescript",
          ],
        },
      },
      {
        test: /\.(woff|woff2|eot|ttf|svg|jpg|gif|webp|png)(\?[a-z0-9]+)?$/,
        loader: "url-loader",
        options: { limit: 1000 },
      },
    ],
  },
};

module.exports = function (_, argv) {
  if (argv.mode === "production") {
    config.entry = "./src/App.tsx";
  }
  return config;
};
